@@ -51,6 +51,7 @@
  */
 
 #include "e-hpaned.h"
+#include "gal/util/e-util.h"
 
 static void     e_hpaned_class_init     (EHPanedClass   *klass);
 static void     e_hpaned_init           (EHPaned        *hpaned);
@@ -58,8 +59,6 @@ static void     e_hpaned_size_request   (GtkWidget      *widget,
 					 GtkRequisition *requisition);
 static void     e_hpaned_size_allocate  (GtkWidget      *widget,
 					 GtkAllocation  *allocation);
-static void     e_hpaned_draw           (GtkWidget      *widget,
-					 GdkRectangle   *area);
 static void     e_hpaned_xor_line       (EPaned         *paned);
 static gboolean e_hpaned_button_press   (GtkWidget      *widget,
 					 GdkEventButton *event);
@@ -69,30 +68,14 @@ static gboolean e_hpaned_motion         (GtkWidget      *widget,
 					 GdkEventMotion *event);
 static gboolean e_hpaned_handle_shown   (EPaned *paned);
 
-GtkType
-e_hpaned_get_type (void)
-{
-  static GtkType hpaned_type = 0;
+#define PARENT_TYPE E_TYPE_PANED
 
-  if (!hpaned_type)
-    {
-      static const GtkTypeInfo hpaned_info =
-      {
-	"EHPaned",
-	sizeof (EHPaned),
-	sizeof (EHPanedClass),
-	(GtkClassInitFunc) e_hpaned_class_init,
-	(GtkObjectInitFunc) e_hpaned_init,
-	/* reserved_1 */ NULL,
-	/* reserved_2 */ NULL,
-	(GtkClassInitFunc) NULL,
-      };
-
-      hpaned_type = gtk_type_unique (E_TYPE_PANED, &hpaned_info);
-    }
-
-  return hpaned_type;
-}
+E_MAKE_TYPE (e_hpaned,
+	     "EHPaned",
+	     EHPaned,
+	     e_hpaned_class_init,
+	     e_hpaned_init,
+	     PARENT_TYPE)
 
 static void
 e_hpaned_class_init (EHPanedClass *klass)
@@ -105,7 +88,6 @@ e_hpaned_class_init (EHPanedClass *klass)
 
   widget_class->size_request = e_hpaned_size_request;
   widget_class->size_allocate = e_hpaned_size_allocate;
-  widget_class->draw = e_hpaned_draw;
   widget_class->button_press_event = e_hpaned_button_press;
   widget_class->button_release_event = e_hpaned_button_release;
   widget_class->motion_notify_event = e_hpaned_motion;
@@ -139,7 +121,7 @@ e_hpaned_new (void)
 {
   EHPaned *hpaned;
 
-  hpaned = gtk_type_new (E_TYPE_HPANED);
+  hpaned = g_object_new (E_TYPE_HPANED, NULL);
 
   return GTK_WIDGET (hpaned);
 }
@@ -283,6 +265,7 @@ e_hpaned_size_allocate (GtkWidget     *widget,
     }
 }
 
+#if 0
 static void
 e_hpaned_draw (GtkWidget    *widget,
 		 GdkRectangle *area)
@@ -311,6 +294,7 @@ e_hpaned_draw (GtkWidget    *widget,
 	gtk_widget_draw(paned->child2, &child_area);
     }
 }
+#endif
 
 static void
 e_hpaned_xor_line (EPaned *paned)
