@@ -434,7 +434,7 @@ ect_free_color (gchar *color_spec, GdkColor *color, GdkColormap *colormap)
 }
 
 static PangoLayout *
-build_layout (ECellTextView *text_view, int row, const char *text)
+build_layout (ECellTextView *text_view, int row, const char *text, gint width)
 {
 	ECellView *ecell_view = (ECellView *) text_view;
 	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
@@ -482,28 +482,63 @@ build_layout (ECellTextView *text_view, int row, const char *text)
 		pango_attr_list_unref (attrs);
 	}
 
+	if (text_view->edit)
+		return layout;
+
+	if (width > 0)
+		pango_layout_set_width (layout, width * PANGO_SCALE);
+	pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
+
+	if (pango_layout_get_line_count (layout) > 1) {
+		PangoLayoutLine *line = pango_layout_get_line (layout, 0);
+		gchar *line_text = g_strdup (pango_layout_get_text (layout));
+		gchar *last_char = g_utf8_find_prev_char (line_text, line_text + line->length - 1);
+		while (last_char && pango_layout_get_line_count (layout) > 1) {
+			gchar *new_text;
+			last_char = g_utf8_find_prev_char (line_text, last_char);
+			if (last_char)
+				*last_char = '\0';
+			new_text = g_strconcat (line_text, "...", NULL);
+			pango_layout_set_text (layout, new_text, -1);
+			g_free (new_text);
+		}
+		g_free (line_text);
+	}
+
+	switch (ect->justify) {
+	case GTK_JUSTIFY_RIGHT:
+		pango_layout_set_alignment (layout, PANGO_ALIGN_RIGHT);
+		break;
+	case GTK_JUSTIFY_CENTER:
+		pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
+		break;
+	case GTK_JUSTIFY_LEFT:
+	default:
+		break;
+	}
+	
 	return layout;
 }
 
 static PangoLayout *
-generate_layout (ECellTextView *text_view, int model_col, int view_col, int row)
+generate_layout (ECellTextView *text_view, int model_col, int view_col, int row, int width)
 {
 	ECellView *ecell_view = (ECellView *) text_view;
 	ECellText *ect = E_CELL_TEXT (ecell_view->ecell);
 	PangoLayout *layout;
 	CellEdit *edit = text_view->edit;
 
-	if (edit && edit->model_col == model_col && edit->row == row) {
+	if (edit && edit->layout && edit->model_col == model_col && edit->row == row) {
 		g_object_ref (edit->layout);
 		return edit->layout;
 	}
 
 	if (row >= 0) {
 		char *temp = e_cell_text_get_text(ect, ecell_view->e_table_model, model_col, row);
-		layout = build_layout (text_view, row, temp);
+		layout = build_layout (text_view, row, temp, width);
 		e_cell_text_free_text(ect, temp);
 	} else
-		layout = build_layout (text_view, row, "Mumbo Jumbo");
+		layout = build_layout (text_view, row, "Mumbo Jumbo", width);
 
 	return layout;
 }
@@ -621,7 +656,7 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	gdk_gc_set_clip_rectangle (text_view->gc, &clip_rect);
 	/*	clip_rect = &rect;*/
 
-	layout = generate_layout (text_view, model_col, view_col, row);
+	layout = generate_layout (text_view, model_col, view_col, row, x2 - x1);
 
 	gdk_draw_layout (drawable, text_view->gc,
 			 x_origin, y_origin,
@@ -940,7 +975,7 @@ ect_height (ECellView *ecell_view, int model_col, int view_col, int row)
 	gint height;
 	PangoLayout *layout;
 
-	layout = generate_layout (text_view, model_col, view_col, row);
+	layout = generate_layout (text_view, model_col, view_col, row, 0);
 	pango_layout_get_pixel_size (layout, NULL, &height);
 	g_object_unref (layout);
 	return height + 2;
@@ -957,15 +992,13 @@ ect_enter_edit (ECellView *ecell_view, int model_col, int view_col, int row)
 	ECellText *ect = E_CELL_TEXT(ecell_view->ecell);
 	char *temp;
 
-	edit = g_new (CellEdit, 1);
+	edit = g_new0 (CellEdit, 1);
 	text_view->edit = edit;
 
 	edit->view_col = -1;
 	edit->model_col = -1;
 	edit->row = -1;
 
-	edit->layout = generate_layout (text_view, model_col, view_col, row);
-	
 	edit->text_view = text_view;
 	edit->model_col = model_col;
 	edit->view_col = view_col;
@@ -974,6 +1007,8 @@ ect_enter_edit (ECellView *ecell_view, int model_col, int view_col, int row)
 		((ETableItem *)ecell_view->e_table_item_view)->header,
 		view_col)->width - 8;
 
+	edit->layout = generate_layout (text_view, model_col, view_col, row, edit->cell_width);
+	
 	edit->xofs_edit = 0.0;
 	edit->yofs_edit = 0.0;
 	
@@ -1139,7 +1174,7 @@ ect_max_width (ECellView *ecell_view,
 	number_of_rows = e_table_model_row_count (ecell_view->e_table_model);
 
 	for (row = 0; row < number_of_rows; row++) {
-		PangoLayout *layout = generate_layout (text_view, model_col, view_col, row);
+		PangoLayout *layout = generate_layout (text_view, model_col, view_col, row, 0);
 		int width;
 
 		pango_layout_get_pixel_size (layout, &width, NULL);
@@ -1165,7 +1200,7 @@ ect_max_width_by_row (ECellView *ecell_view,
 	if (row >= e_table_model_row_count (ecell_view->e_table_model))
 		return 0;
 
-	layout = generate_layout (text_view, model_col, view_col, row);
+	layout = generate_layout (text_view, model_col, view_col, row, 0);
 	pango_layout_get_pixel_size (layout, &width, NULL);
 	g_object_unref (layout);
 	
@@ -1239,7 +1274,7 @@ ect_show_tooltip (ECellView *ecell_view,
 
 	tooltip->timer = 0;
 
-	layout = generate_layout (text_view, model_col, view_col, row);
+	layout = generate_layout (text_view, model_col, view_col, row, col_width);
 
 	pango_layout_get_pixel_size (layout, &width, &height);
 	if (width < col_width - 8) {
@@ -1597,7 +1632,7 @@ get_position_from_xy (CellEdit *edit, gint x, gint y)
 	int index;
 	int trailing;
 	const char *text;
-	PangoLayout *layout = edit->layout;
+	PangoLayout *layout = generate_layout (edit->text_view, edit->model_col, edit->view_col, edit->row, edit->cell_width);
 	ECellTextView *text_view = edit->text_view;
 	ECellText *ect = (ECellText *) ((ECellView *)text_view)->ecell;
 
@@ -2070,7 +2105,7 @@ e_cell_text_view_command (ETextEventProcessor *tep, ETextEventProcessorCommand *
 	if (change) {
 		if (edit->layout)
 			g_object_unref (edit->layout);
-		edit->layout = build_layout (text_view, edit->row, edit->text);
+		edit->layout = build_layout (text_view, edit->row, edit->text, edit->cell_width);
 	}
 
 	if (!edit->button_down) {
