@@ -983,6 +983,8 @@ e_tree_table_adapter_load_expanded_state (ETreeTableAdapter *etta, const char *f
 		path = e_tree_model_get_node_by_id(etta->priv->source, id);
 		if (path)
 			e_tree_table_adapter_node_set_expanded(etta, path, !model_default);
+
+		g_free (id);
 	}
 
 	xmlFreeDoc (doc);
@@ -1152,3 +1154,13 @@ e_tree_table_adapter_set_sort_info (ETreeTableAdapter *etta, ETableSortInfo *sor
 	e_table_model_changed(E_TABLE_MODEL(etta));
 }
 
+ETreePath
+e_tree_table_adapter_node_get_next (ETreeTableAdapter *etta, ETreePath path)
+{
+	GNode *node = lookup_gnode (etta, path);
+
+	if (node && node->next)
+		return ((node_t *)node->next->data)->path;
+
+	return NULL;
+}
