@@ -239,12 +239,14 @@ collection_changed (GalView *view, GalViewInstance *instance)
 static void
 load_current_view (GalViewInstance *instance)
 {
-	xmlDoc *doc;
+	xmlDoc *doc = NULL;
 	xmlNode *root;
 	GalView *view = NULL;
-
-	doc = xmlParseFile(instance->current_view_filename);
-
+	struct stat st;
+	
+	if (stat (instance->current_view_filename, &st) != -1 && S_ISREG (st.st_mode))
+		doc = xmlParseFile(instance->current_view_filename);
+	
 	if (doc == NULL) {
 		instance->current_id = g_strdup (gal_view_instance_get_default_view (instance));
 
@@ -575,9 +577,12 @@ gal_view_instance_get_popup_menu (GalViewInstance *instance)
 	}
 
 	e_popup_menu_copy_1 (ret_val + i++, &separator);
-	add_popup_menu_item (ret_val + i++, N_("Define Views"), G_CALLBACK (define_views_cb), instance);
+	add_popup_menu_item (ret_val + i++, N_("Define Views..."), G_CALLBACK (define_views_cb), instance);
 	e_popup_menu_copy_1 (ret_val + i++, &terminator);
 
+	if (id)
+		g_free (id);
+
 	return ret_val;
 }
 
