@@ -187,6 +187,10 @@ e_icon_bar_bg_item_draw (GnomeCanvasItem *canvas_item, GdkDrawable *drawable,
 	style = GTK_WIDGET (icon_bar)->style;
 	shadow = GTK_SHADOW_NONE;
 
+	gtk_paint_flat_box (style, drawable, GTK_STATE_ACTIVE, GTK_SHADOW_OUT,
+			    NULL, GTK_WIDGET (icon_bar), "EIconBar",
+			    x, y, width, height);
+
 	/* Draw the highlight around the current highlight item. */
 	item_num = -1;
 	if (icon_bar->editing_item_num == -1) {
@@ -211,11 +215,14 @@ e_icon_bar_bg_item_draw (GnomeCanvasItem *canvas_item, GdkDrawable *drawable,
 		else
 			border = E_ICON_BAR_SMALL_ICON_SHADOW_BORDER;
 
-		gtk_draw_shadow (style, drawable, GTK_STATE_NORMAL, shadow,
-				 icon_bar->icon_x - border - x,
-				 item->icon_y - border - y,
-				 icon_bar->icon_w + border * 2 - 1,
-				 icon_bar->icon_h + border * 2 - 1);
+		gtk_paint_shadow (style, drawable,
+				  GTK_STATE_ACTIVE, shadow,
+				  NULL, GTK_WIDGET (icon_bar),
+				  "EIconBarItem",
+				  icon_bar->icon_x - border - x,
+				  item->icon_y - border - y,
+				  icon_bar->icon_w + border * 2 - 1,
+				  icon_bar->icon_h + border * 2 - 1);
 	}
 
 	/* Draw the bar between items when dragging, if needed. */
